pub struct VertexLayoutDesc {
pub stride: u32,
pub step_mode: VertexStepMode,
}Expand description
Describes vertex buffer layout.
Fields
stride: u32Stride in bytes between vertices in the vertex buffer.
step_mode: VertexStepModeSpecifies when to advance to the next vertex (by stride bytes).