pub struct mat<T, const N: usize, const M: usize>(pub [vec<T, M>; N]);Expand description
Matrix data type.
Element type should be Scalar, then it can be used as device data type.
Tuple Fields
0: [vec<T, M>; N]Trait Implementations
impl<T: Copy, const N: usize, const M: usize> Copy for mat<T, N, M>
Sourceimpl<T, const N: usize> DeviceRepr for mat<T, N, 2>where
T: Scalar,
impl<T, const N: usize> DeviceRepr for mat<T, N, 2>where
T: Scalar,
Sourcetype Repr = mat<<T as Scalar>::ScalarRepr, N, 2>
type Repr = mat<<T as Scalar>::ScalarRepr, N, 2>
A POD type that can represent same data with layout compatible with shaders.
It is
Self or another type with same data and manual padding.Sourcetype ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 2>
type ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 2>
A POD type with layout compatible with shaders.
This is the same as
Self::Repr but with tail padding up to Self::ALIGN.fn make_array_repr(&self) -> Self::ArrayRepr
Sourcefn as_array_repr(&self) -> Self::ArrayRepr
fn as_array_repr(&self) -> Self::ArrayRepr
Construct a
Self::ArrayRepr from &self.Sourcefn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
fn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
Return byte representation of
ArrayRepr slice.Sourceconst ARRAY_SIZE: usize = _
const ARRAY_SIZE: usize = _
Size of array repr type.
Sourceimpl<T, const N: usize> DeviceRepr for mat<T, N, 3>where
T: Scalar,
impl<T, const N: usize> DeviceRepr for mat<T, N, 3>where
T: Scalar,
Sourcetype Repr = mat<<T as Scalar>::ScalarRepr, N, 4>
type Repr = mat<<T as Scalar>::ScalarRepr, N, 4>
A POD type that can represent same data with layout compatible with shaders.
It is
Self or another type with same data and manual padding.Sourcetype ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 4>
type ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 4>
A POD type with layout compatible with shaders.
This is the same as
Self::Repr but with tail padding up to Self::ALIGN.fn make_array_repr(&self) -> Self::ArrayRepr
Sourcefn as_array_repr(&self) -> Self::ArrayRepr
fn as_array_repr(&self) -> Self::ArrayRepr
Construct a
Self::ArrayRepr from &self.Sourcefn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
fn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
Return byte representation of
ArrayRepr slice.Sourceconst ARRAY_SIZE: usize = _
const ARRAY_SIZE: usize = _
Size of array repr type.
Sourceimpl<T, const N: usize> DeviceRepr for mat<T, N, 4>where
T: Scalar,
impl<T, const N: usize> DeviceRepr for mat<T, N, 4>where
T: Scalar,
Sourcetype Repr = mat<<T as Scalar>::ScalarRepr, N, 4>
type Repr = mat<<T as Scalar>::ScalarRepr, N, 4>
A POD type that can represent same data with layout compatible with shaders.
It is
Self or another type with same data and manual padding.Sourcetype ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 4>
type ArrayRepr = mat<<T as Scalar>::ScalarRepr, N, 4>
A POD type with layout compatible with shaders.
This is the same as
Self::Repr but with tail padding up to Self::ALIGN.fn make_array_repr(&self) -> Self::ArrayRepr
Sourcefn as_array_repr(&self) -> Self::ArrayRepr
fn as_array_repr(&self) -> Self::ArrayRepr
Construct a
Self::ArrayRepr from &self.Sourcefn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
fn as_array_bytes(repr: &[Self::ArrayRepr]) -> &[u8] ⓘ
Return byte representation of
ArrayRepr slice.Sourceconst ARRAY_SIZE: usize = _
const ARRAY_SIZE: usize = _
Size of array repr type.
impl<T: Eq, const N: usize, const M: usize> Eq for mat<T, N, M>
Sourceimpl<T: PartialEq, const N: usize, const M: usize> PartialEq for mat<T, N, M>
impl<T: PartialEq, const N: usize, const M: usize> PartialEq for mat<T, N, M>
impl<T, const N: usize, const M: usize> Pod for mat<T, N, M>where
T: Pod,
impl<T: PartialEq, const N: usize, const M: usize> StructuralPartialEq for mat<T, N, M>
Sourceimpl<T, const M: usize> VertexAttributes for mat<T, 2, M>where
vec<T, M>: VertexAttributes,
impl<T, const M: usize> VertexAttributes for mat<T, 2, M>where
vec<T, M>: VertexAttributes,
const FORMAT: VertexFormat = <vec<T, M> as VertexAttributes>::FORMAT
const COUNT: VectorSize = VectorSize::Two
Sourceimpl<T, const M: usize> VertexAttributes for mat<T, 3, M>where
vec<T, M>: VertexAttributes,
impl<T, const M: usize> VertexAttributes for mat<T, 3, M>where
vec<T, M>: VertexAttributes,
const FORMAT: VertexFormat = <vec<T, M> as VertexAttributes>::FORMAT
const COUNT: VectorSize = VectorSize::Three
Sourceimpl<T, const M: usize> VertexAttributes for mat<T, 4, M>where
vec<T, M>: VertexAttributes,
impl<T, const M: usize> VertexAttributes for mat<T, 4, M>where
vec<T, M>: VertexAttributes,
const FORMAT: VertexFormat = <vec<T, M> as VertexAttributes>::FORMAT
const COUNT: VectorSize = VectorSize::Four