pub struct SamplerDesc {
pub min_filter: Filter,
pub mag_filter: Filter,
pub mip_map_mode: MipMapMode,
pub address_mode: [AddressMode; 3],
pub anisotropy: Option<f32>,
pub min_lod: f32,
pub max_lod: f32,
pub normalized: bool,
}Expand description
Describes how to sample the texture.
Fields
min_filter: FilterFilter to use when sampling the texture with pixels smaller than fragment.
mag_filter: FilterFilter to use when sampling the texture with pixels larger than fragment.
mip_map_mode: MipMapModeMip-map mode to use when sampling the texture.
address_mode: [AddressMode; 3]Address mode to use when sampling the texture, for each dimension.
anisotropy: Option<f32>Maximum anisotropy level to use when sampling the texture.
min_lod: f32Minimum level of detail to use when sampling the texture.
max_lod: f32Maximum level of detail to use when sampling the texture.
normalized: boolWhether to normalize the texture coordinates. If true, 0.0 and 1.0 are treated as edges of the texture. Otherwise 1.0 is size of one texel.
Implementations
Sourceimpl SamplerDesc
impl SamplerDesc